==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification.md <==
# AmazonSimpleNotificationServiceHttpNotification


```text
aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification
```

```text
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')
```



| Illustration | AmazonSimpleNotificationServiceHttpNotification | AmazonSimpleNotificationServiceHttpNotificationCard | AmazonSimpleNotificationServiceHttpNotificationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification.png) | ![illustration for AmazonSimpleNotificationServiceHttpNotification](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification.Local.png) | ![illustration for AmazonSimpleNotificationServiceHttpNotificationCard](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotificationCard.Local.png) | ![illustration for AmazonSimpleNotificationServiceHttpNotificationGroup](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotificationGroup.Local.png) |




## AmazonSimpleNotificationServiceHttpNotification

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotification
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotification('AmazonSimpleNotificationServiceHttpNotification', 'Amazon Simple Notification Service Http Notification', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotification
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotification('AmazonSimpleNotificationServiceHttpNotification', 'Amazon Simple Notification Service Http Notification', 'an optional tech label')
@enduml
```

## AmazonSimpleNotificationServiceHttpNotificationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotificationCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotificationCard('AmazonSimpleNotificationServiceHttpNotificationCard', 'Amazon Simple Notification Service Http Notification Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotificationCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotificationCard('AmazonSimpleNotificationServiceHttpNotificationCard', 'Amazon Simple Notification Service Http Notification Card', 'an optional description')
@enduml
```

## AmazonSimpleNotificationServiceHttpNotificationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotificationGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotificationGroup('AmazonSimpleNotificationServiceHttpNotificationGroup', 'Amazon Simple Notification Service Http Notification Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotificationGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotificationGroup('AmazonSimpleNotificationServiceHttpNotificationGroup', 'Amazon Simple Notification Service Http Notification Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification.md <==
# AmazonSimpleNotificationServiceHttpNotification


```text
aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification
```

```text
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')
```



| Illustration | AmazonSimpleNotificationServiceHttpNotification | AmazonSimpleNotificationServiceHttpNotificationCard | AmazonSimpleNotificationServiceHttpNotificationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification.png) | ![illustration for AmazonSimpleNotificationServiceHttpNotification](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification.Local.png) | ![illustration for AmazonSimpleNotificationServiceHttpNotificationCard](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotificationCard.Local.png) | ![illustration for AmazonSimpleNotificationServiceHttpNotificationGroup](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotificationGroup.Local.png) |




## AmazonSimpleNotificationServiceHttpNotification

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotification
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotification('AmazonSimpleNotificationServiceHttpNotification', 'Amazon Simple Notification Service Http Notification', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotification
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotification('AmazonSimpleNotificationServiceHttpNotification', 'Amazon Simple Notification Service Http Notification', 'an optional tech label')
@enduml
```

## AmazonSimpleNotificationServiceHttpNotificationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotificationCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotificationCard('AmazonSimpleNotificationServiceHttpNotificationCard', 'Amazon Simple Notification Service Http Notification Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotificationCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotificationCard('AmazonSimpleNotificationServiceHttpNotificationCard', 'Amazon Simple Notification Service Http Notification Card', 'an optional description')
@enduml
```

## AmazonSimpleNotificationServiceHttpNotificationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotificationGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotificationGroup('AmazonSimpleNotificationServiceHttpNotificationGroup', 'Amazon Simple Notification Service Http Notification Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceHttpNotificationGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceHttpNotification')

' renders the element
AmazonSimpleNotificationServiceHttpNotificationGroup('AmazonSimpleNotificationServiceHttpNotificationGroup', 'Amazon Simple Notification Service Http Notification Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
